package com.ys.bdtp.adm.mvvm.model.nt

import com.ys.bdtp.adm.mvvm.model.Model
import com.ys.bdtp.adm.mvvm.model.vo.*
import com.ys.bdtp.adm.mvvm.model.vo.request.Account
import com.ys.bdtp.adm.mvvm.model.vo.request.Login
import retrofit2.http.Body
import retrofit2.http.Headers
import retrofit2.http.POST

/**
 * 后端API
 *
 * @author bai
 */
interface Api {
    /**
     * 登录接口,登录只获取token
     *
     * @param login 登录参数
     * @return [Model] 返回token
     */
    @POST("auth/account/login")
    suspend fun login(@Body login: Login): Model<String>

    /**
     *  获取账号信息
     */
    @POST("auth/login/loginInfo")
    suspend fun getAccount(): Model<Account>

    /**
     * 获取字典数据
     */
    @POST("adm/dict")
    suspend fun getDict(@Body body: Map<String, String>): Model<Dict>

    /**
     * 获取配置信息
     */
    @POST("adm/config")
    suspend fun getConfig(@Body map: Map<String, String>): Model<Config>

    /**
     * 获取建筑和楼层数据
     */
    @POST("adm/frame")
    suspend fun getBuildingsAndFloors(@Body map: Map<String, String>): Model<BuildingsAndFloors>

    /**
     * 下载任务数据
     */
    @POST("adm/download")
    suspend fun getMission(@Body map: Map<String, String>): Model<Mission>

    /**
     * 上传任务数据
     */
    @Headers("Content-Encoding: gzip")
    @POST("adm/upload")
    suspend fun uploadMission(@Body mission: Mission)

    /**
     * 获取关系数据
     */
    @POST("adm/downloadObjRel")
    suspend fun getRelation(@Body map: Map<String, String>): Model<Relation>

    /**
     * 判断是否有需要更新的数据
     */
    @POST("adm/hasUpdate")
    suspend fun hasUpdate(): Model<Boolean>

    /**
     * 文件上传
     */
    @POST("adm/uploadFile")
    suspend fun uploadFile()

    /**
     * 下载地图
     */
    @POST("adm/downloadMap")
    suspend fun downloadFile()


}